<?php
/**
 * Green Farm Elementor Theme page
 *
 * @package Green Farm Elementor
 */

if ( ! defined( 'GREEN_FARM_ELEMENTOR_SUPPORT' ) ) {
	define( 'GREEN_FARM_ELEMENTOR_SUPPORT', 'https://wordpress.org/support/theme/green-farm-elementor' );
}
if ( ! defined( 'GREEN_FARM_ELEMENTOR_REVIEW' ) ) {
	define( 'GREEN_FARM_ELEMENTOR_REVIEW', 'https://wordpress.org/support/theme/green-farm-elementor/reviews/#new-post' );
}
if ( ! defined( 'GREEN_FARM_ELEMENTOR_LIVE_DEMO' ) ) {
	define( 'GREEN_FARM_ELEMENTOR_LIVE_DEMO', 'https://www.wpelemento.com/demo/elementor-green-farm/' );
}
if ( ! defined( 'GREEN_FARM_ELEMENTOR_BUY_NOW' ) ) {
	define( 'GREEN_FARM_ELEMENTOR_BUY_NOW', 'https://www.wpelemento.com/elementor/green-farm-wordpress-theme/' );
}

//Admin Enqueue for Admin
function green_farm_elementor_admin_enqueue_scripts(){
	wp_enqueue_style('green-farm-elementor-admin-style', esc_url( get_template_directory_uri() ) . '/includes/about-theme/css/admin.css');
}
add_action( 'admin_enqueue_scripts', 'green_farm_elementor_admin_enqueue_scripts' );

/**
 * Add theme page
 */
function green_farm_elementor_menu() {
	add_theme_page( esc_html__( 'About Theme', 'green-farm-elementor' ), esc_html__( 'About Theme', 'green-farm-elementor' ), 'edit_theme_options', 'green-farm-elementor-about', 'green_farm_elementor_about_display' );
}
add_action( 'admin_menu', 'green_farm_elementor_menu' );

/**
 * Display About page
 */
function green_farm_elementor_about_display() {
	$green_farm_elementor_content_theme = wp_get_theme(); ?>
	<div class="wrap about-wrap full-width-layout">
		<div class="about-theme">
			<h1><?php echo esc_html( $green_farm_elementor_content_theme ); ?></h1>
			<div class="theme-description">
				<p class="about-text">
					<?php
					// Remove last sentence of description.
					$green_farm_elementor_description = explode( '. ', $green_farm_elementor_content_theme->get( 'Description' ) );

					array_pop( $green_farm_elementor_description );

					$green_farm_elementor_description = implode( '. ', $green_farm_elementor_description );

					echo esc_html( $green_farm_elementor_description . '.' );
				?></p>
			</div>
		</div>

		<?php
			green_farm_elementor_main_screen();
		?>

		<div class="return-to-dashboard">
			<?php if ( current_user_can( 'update_core' ) && isset( $_GET['updated'] ) ) : ?>
				<a href="<?php echo esc_url( self_admin_url( 'update-core.php' ) ); ?>">
					<?php is_multisite() ? esc_html_e( 'Return to Updates', 'green-farm-elementor' ) : esc_html_e( 'Return to Dashboard &rarr; Updates', 'green-farm-elementor' ); ?>
				</a> |
			<?php endif; ?>
			<a href="<?php echo esc_url( self_admin_url() ); ?>"><?php is_blog_admin() ? esc_html_e( 'Go to Dashboard &rarr; Home', 'green-farm-elementor' ) : esc_html_e( 'Go to Dashboard', 'green-farm-elementor' ); ?></a>
		</div>
	</div>
	<?php
}

/**
 * Output the main about screen.
 */
function green_farm_elementor_main_screen() {
	$green_farm_elementor_content_theme = wp_get_theme(); ?>
	<div class="feature-section">
		<div class="card">
			<h2 class="title"><?php esc_html_e( 'Theme Customizer', 'green-farm-elementor' ); ?></h2>
			<p><?php esc_html_e( 'Easy Customization options are available on custumizer screen.', 'green-farm-elementor' ) ?></p>
			<p><a href="<?php echo esc_url( admin_url( 'customize.php' ) ); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'Customize', 'green-farm-elementor' ); ?></a></p>
		</div>

		<div class="card">
			<h2 class="title"><?php esc_html_e( 'Support', 'green-farm-elementor' ); ?></h2>
			<p><?php esc_html_e( 'Get quick support from genuine people who deliver tailored solutions to your questions.', 'green-farm-elementor' ) ?></p>
			<p><a href="<?php echo esc_url( GREEN_FARM_ELEMENTOR_SUPPORT ); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'Support', 'green-farm-elementor' ); ?></a></p>
		</div>

		<div class="card">
			<h2 class="title"><?php esc_html_e( 'Review', 'green-farm-elementor' ); ?></h2>
			<p><?php esc_html_e( 'Show us support by reveiwing our theme. Click here to leave your reveiw.', 'green-farm-elementor' ) ?></p>
			<p><a href="<?php echo esc_url( GREEN_FARM_ELEMENTOR_REVIEW ); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'Review', 'green-farm-elementor' ); ?></a></p>
		</div>
	</div>
	<div class="pro-feature-section">
		<h2 class="title"><?php esc_html_e( 'Green Farm Elementor Pro', 'green-farm-elementor' ); ?></h2>
		<div class="pro-buttons">
			<a href="<?php echo esc_url( GREEN_FARM_ELEMENTOR_LIVE_DEMO ); ?>" class="button button-primary live-preview" target="_blank"><?php esc_html_e( 'Live Preview', 'green-farm-elementor' ); ?></a>
			<a href="<?php echo esc_url( GREEN_FARM_ELEMENTOR_BUY_NOW ); ?>" class="button button-primary buy-nw" target="_blank"><?php esc_html_e( 'Buy Now', 'green-farm-elementor' ); ?></a>
		</div>
		<img src="<?php echo esc_url( $green_farm_elementor_content_theme->get_screenshot() ); ?>" />
	</div>
	<?php
}
